#
# spec file for package mcelog
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mcelog
Summary:        Log Machine Check Events
License:        GPL-2.0
Group:          System/Monitoring
Version:        1.20
Release:        4.5
ExclusiveArch:  %{ix86} x86_64
BuildRequires:  libesmtp-devel
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires:       logrotate
Source:         mcelog-%{version}.tar.bz2
Source2:        mcelog.sysconfig
Source3:        mcelog.systemd
Source4:        90-mcelog.rules
Source5:        mcelog.tmpfiles
Source6:        README.email_setup
Patch1:         email.patch
Patch2:         mcelog_invert_prefill_db_warning.patch
Patch3:         Start-consolidating-AMD-specific-stuff.patch
Patch4:         patches/add-defines.patch
Patch5:         patches/add-f10h-support.patch
Patch6:         patches/add-f11h-support.patch
Patch7:         patches/add-f12h-support.patch
Patch8:         patches/add-f14h-support.patch
Patch9:         patches/add-f15h-support.patch
Patch10:        patches/add-f16h-support.patch
Patch11:        mcelog-socket-path.patch
Patch12:        fix_setgroups_missing_call.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %fillup_prereq
Url:            https://git.kernel.org/cgit/utils/cpu/mce/mcelog.git
# Previously version was wrong, mainline decided to go for 1.0.1. not 1.1
Obsoletes:      mcelog = 1.1
%{?systemd_requires}

%description
mcelog retrieves machine check events from an x86-64 kernel in a cron
job, decodes them, and logs them to /var/log/mcelog.

A machine check event is a hardware error detected by the CPU.

It should run on any x86-64 system.

In addition, it allows decoding machine check kernel panic messages.



Authors:
--------
    Andi Kleen <andi@firstfloor.org>

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1

%build
export SUSE_ASNEEDED=0
make CFLAGS="$RPM_OPT_FLAGS"

%install 
export prefix=$RPM_BUILD_ROOT/usr
export etcprefix=$RPM_BUILD_ROOT
make -e install
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d/
install -m644 mcelog.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/mcelog

mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 644 %SOURCE2 $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.mcelog

mkdir -p $RPM_BUILD_ROOT/%_docdir/%name
install -m 644 %SOURCE6 $RPM_BUILD_ROOT/%_docdir/%name/README.email_setup
install -m 644 lk10-mcelog.pdf $RPM_BUILD_ROOT/%_docdir/%name/lk10-mcelog.pdf
install -D -m 0644 %SOURCE3 %{buildroot}%{_unitdir}/mcelog.service
install -D -m 0644 %SOURCE4 %{buildroot}%{_udevrulesdir}/90-mcelog.rules
install -D -m 0644 %SOURCE5 %{buildroot}%{_tmpfilesdir}/mcelog.conf
ln -sf %_sbindir/service ${RPM_BUILD_ROOT}%_sbindir/rcmcelog

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%service_add_pre %{name}.service

%post
%fillup_only
%{?tmpfiles_create:%tmpfiles_create %{_tmpfilesdir}/mcelog.conf}
%udev_rules_update

%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr (-,root,root,755)
%{_mandir}/man8/*
%{_mandir}/man5/*
/usr/sbin/mcelog
%config /etc/logrotate.d/mcelog
%dir /etc/mcelog
%config /etc/mcelog/mcelog.conf
/var/adm/fillup-templates/sysconfig.mcelog
/etc/mcelog/*trigger
%{_unitdir}/mcelog.service
%{_udevrulesdir}/90-mcelog.rules
%{_tmpfilesdir}/mcelog.conf
%_docdir/%name
%_sbindir/rcmcelog
%ghost /run/mcelog

%changelog
* Mon Jun 15 2015 trenn@suse.de
- Update to latest v120 git tag and name the version 1.20:
  New supported CPUs:
  - Add model number for Broadwell-DE
  - Added Knights Landing (Xeon Phi)
  - Add all current Atom cpuids
  - Support Broadwell-U
  - New manpages: mcelog.conf.5 and mcelog.triggers.5
  And quite some undocumented bugfixes, see git log for details
* Fri Jan 23 2015 trenn@suse.de
- Update to version 1.0.8
- Remove patch which got integrated mainline:
  0001-Continue-without-dmi-when-no-SMBIOS-or-SMBIOS-0x0-in.patch
- Fix possible security issue, build service complained about:
  missing-call-to-setgroups-before-setuid
  Add fix_setgroups_missing_call.patch
* Fri Nov 14 2014 crrodriguez@opensuse.org
- While not yet defined, the tmpfiles_create macro takes
  an argument for it to actually work
* Sat Sep 20 2014 crrodriguez@opensuse.org
- mcelog.tmpfiles, mcelog-socket-path.patch, move socket
  and pid file to /run/mcelog directory.
  This update may require reboot as the relevant rpm macro
  tmpfiles_create is not yet in any product.
* Wed Sep  3 2014 trenn@suse.de
- Fixed the architecture tag to %%{ix86} as suggested by:
  Andreas Vetter <asvetter@cip.physik.uni-wuerzburg.de>
* Wed Sep  3 2014 meissner@suse.com
- fixed the architecture tag to %%ix86
* Fri Jul 11 2014 juwolf@suse.com
- Fixed license, GPL-2.0
* Fri Jun 27 2014 juwolf@suse.com
- Added: 0001-Continue-without-dmi-when-no-SMBIOS-or-SMBIOS-0x0-in.patch
  Continue without dmi when no SMBIOS or SMBIOS=0x0 in /sys/firmware/efi/systab, bnc#829862
* Fri May 16 2014 trenn@suse.de
- Add mce decoding support for latest AMD CPUs (bnc#871881).
- Implementation done by Borislav Petkov <bp@suse.de>
  * Add patches/Start-consolidating-AMD-specific-stuff.patch
  * Add add-defines.patch
  * Add add-f10h-support.patch
  * Add add-f11h-support.patch
  * Add add-f12h-support.patch
  * Add add-f14h-support.patch
  * Add add-f15h-support.patch
  * Add add-f16h-support.patch
* Mon Apr 28 2014 trenn@suse.de
- Update to latest git tag v101.
- Mainline decided to finally do a version upgrade to v101
- Remove v1.1 again, obsolete it and go for version v102
- Some important fixes in the latest update:
  - bnc#873159
  - bnc#873725
* Sun Oct 27 2013 crrodriguez@opensuse.org
- Cleanup spec file
- activate mcelog service via udev+systemd combo, if the kernel
  registers a /dev/mcelog device the service will be automatically
  started.
- drop sysvinit scripts, add appropiate %%pre %%post invocations
  of the needed systemd macros.
* Tue Oct 15 2013 trenn@suse.de
- Updated to latest git HEAD:
    commit c7bf28088f056925c04d4fd5768504c59bbf19c4
    Author: Robin Holt <robinmholt@gmail.com>
    Date:   Mon Sep 16 04:30:02 2013 -0500
  Because upstream does not use proper tags/revisions, I now
  versioned this one mcelog-1.1
* Fri Feb 22 2013 rmilasan@suse.com
- Install mcelog.service accordingly (/usr/lib/systemd for 12.3
  and up or /lib/systemd for older versions).
* Thu Aug 16 2012 trenn@suse.de
- bnc#774226 mcelog + systemd: won't start without MCELOG_ADMIN_EMAIL set
- fix uninitialized variable mail_setup
* Wed Jul 18 2012 trenn@suse.de
- Also build mcelog packages for i386 (bnc#770726)
* Tue Apr 24 2012 avm-xandry@yandex.ru
- Fixed description in init-file.
* Wed Nov 23 2011 crrodriguez@opensuse.org
- Add systemd unit.
* Wed Aug 17 2011 ro@suse.de
- update to GIT of today (6e4e2a000124f08f1a4e3791c2b02ec9ae6af393)
- many bugfixes
- Implement re-parsing of mcelog output in ASCII
- Add support for non-page aligned EFI Configuration Tables
- Add --debug-numerrors
- Add decoder for corrected XEN events to --ascii
- Correctly log kernel supplied time
- record the trigger info in the log
- mcelog: Implement dmi decoding for UEFI
- mcelog: Add usage information to mcelog for --ignorenodev
- Fix length calculation of SMBIOS mapping
- change disclaimer
- explictly spell out corrected errors
* Sat Jul  2 2011 trenn@suse.de
- Update to latest git version (fate#311830)
  Unfortunately versions have not been increased, latest tag
  still is 1.0-pre3 (same as 1 year ago), therefore the date
  is included in the version. I try to push maintainers to
  increase the version number.
- Invert logic of db prefill messages -> info if it works, silent
  if not
* Tue Jun  7 2011 trenn@suse.de
- Remove test email address from config
* Mon Oct 25 2010 trenn@suse.de
- Add Sandybridge/Westmere decode support
- Fix domainname for email notification
- Update to latest git version
* Tue Apr  6 2010 trenn@suse.de
- Update to latest git version having quite some fixes (no features):
  - Fixed some memleaks and made app valgrind conform
  - Fixed theoretical DoS attack (bnc#586241)
  - Added support of additional cpus
  - Fixed a lot messages (in manpage, in triggers, in README, ...)
* Thu Feb 18 2010 ro@suse.de
- Update to version 1.0pre3
  - Boxboro-EX enhancements
  - Bugfixes
  Minor pidfile handling adjusting in service file
- Added missing conf file and trigger scripts
* Thu Dec  3 2009 trenn@suse.de
- Minor .spec and init script fixes/cleanups
* Thu Dec  3 2009 trenn@suse.de
- Add service parts:
  - let mcelog --daemon handle pid file in /var/run/mcelog.pid
  - add insserv logic
  - remove cron.daily script in update case
* Fri Nov 27 2009 trenn@suse.de
- Update to latest git version (called it 1.0pre1 myself, may differ
  with a possible public 1.0pre1 version), this includes
  following new featues:
  - yellow bit support
  - page predictive failure analysis support
  - Initial memdb support
    This allows to account memory errors in memory in daemon mode
    And a lot more...
* Fri Oct  2 2009 trenn@suse.de
- Update to latest git version (0.9pre)
  Introduces mcelog damon mode, service file will follow in an
  extra commit.
* Fri Jan  9 2009 olh@suse.de
- use ExclusiveArch as in /SRC/arch/
* Sat Sep 27 2008 trenn@suse.de
- fate #304279 mcelog support for Tigerton/Dunnington
  Patch is from Andi himself with this statement:
  While it looks large most of it is just new tables.
* Mon May 29 2006 ak@suse.de
- decode intel thermal events too (#179327)
* Fri May  5 2006 ak@suse.de
- Update to 0.7.  This fixes
  - Fix --dmi option (#166324)
  - Incorporate old patches
* Fri Mar  3 2006 ak@suse.de
- Avoid cosmetic problem in --filter (#153347)
* Wed Feb  8 2006 ak@suse.de
- update to mcelog 0.6
  * Fixes bugs (#148869, #137985)
  * Adds --dmi option to map addresses to DIMMs using SMBIOS
    (default to off)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 sf@suse.de
- update to version 0.5
  * Clarify --ascii in the manpage
  * Support for AMD K8 Revision F machine check DRAM error
  thresholding
* Fri Feb 11 2005 ak@suse.de
- Use RPM_OPT_FLAGS
- Improve description again
* Thu Feb 10 2005 ak@suse.de
- mcelog-0.4:
  * add support to decode AMD K8 (Opteron/Athlon64/AthlonFX) and
    Intel P4 (Xeon and Pentium 4) events
  * add --ascii option to decode machine check panic information
- Rewrite description in .spec file
* Wed Jun  9 2004 ak@suse.de
- memlog-0.2:
  * fix mcelog looping (#41863)
  * Add GPL notices
* Thu Mar 25 2004 sf@suse.de
- initial version
- fixes #36898
